@@ -422,10 +422,10 @@ void RenderWidget::updateFromElement()
                     QPalette::ColorRole cr;
                 };
                 const struct ColorSet toSet [] = {
-                    { QPalette::Active, QPalette::Foreground },
+                    { QPalette::Active, QPalette::WindowText },
                     { QPalette::Active, QPalette::ButtonText },
                     { QPalette::Active, QPalette::Text },
-                    { QPalette::Inactive, QPalette::Foreground },
+                    { QPalette::Inactive, QPalette::WindowText },
                     { QPalette::Inactive, QPalette::ButtonText },
                     { QPalette::Inactive, QPalette::Text },
                     { QPalette::NColorGroups, QPalette::NColorRoles },
@@ -450,10 +450,10 @@ void RenderWidget::updateFromElement()
 		    // for really dark fg - use darkgray disabled fg,
 		    // as ::light is pretty useless in this range
 		    disfg = Qt::darkGray;
-		pal.setColor(QPalette::Disabled,QPalette::Foreground,disfg);
+		pal.setColor(QPalette::Disabled,QPalette::WindowText,disfg);
 		pal.setColor(QPalette::Disabled,QPalette::Text,disfg);
 		pal.setColor(QPalette::Disabled,QPalette::ButtonText,disfg);
-                non_trans_pal.setColor(QPalette::Disabled,QPalette::Foreground,disfg);
+                non_trans_pal.setColor(QPalette::Disabled,QPalette::WindowText,disfg);
                 non_trans_pal.setColor(QPalette::Disabled,QPalette::Text,disfg);
                 non_trans_pal.setColor(QPalette::Disabled,QPalette::ButtonText,disfg);
             }
@@ -497,9 +497,6 @@ void RenderWidget::updateFromElement()
         } else if (QLineEdit* lineEdit = qobject_cast<QLineEdit*>(m_widget)) {
             lineEdit->setFrame(!shouldDisableNativeBorders()); 
         }
-
-        // Font:
-        setStyle(style());
     }
 
     RenderReplaced::updateFromElement();
@@ -512,7 +509,6 @@ void RenderWidget::paintOneBackground(QPainter *p, const QColor& c, const Backgr
                                 fudge ? 1 : borderLeft() , fudge ? 1 : borderRight(), paddingLeft(), paddingRight(),
                                 fudge ? 1 : borderTop(), fudge ? 1 : borderBottom(), paddingTop(), paddingBottom());
 }
-                             
 
 void RenderWidget::paintBoxDecorations(PaintInfo& paintInfo, int _tx, int _ty)
 {
@@ -1034,7 +1030,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
             p.setY(qMin(qMax(0,p.y()),m_widget->height()));
         }
 
-        QWidget* target = 0;
+        QPointer<QWidget> target;
         target = m_widget->childAt(p);
 
         if (target) {
@@ -1107,16 +1103,18 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
             }
         }
 
-        QEvent *e = isMouseWheel ?
+        QScopedPointer<QEvent> e(isMouseWheel ?
                     static_cast<QEvent*>(new QWheelEvent(p, -me.detail()*40, buttons, state, orient)) :
-                    static_cast<QEvent*>(new QMouseEvent(type,    p, button, buttons, state));
+                    static_cast<QEvent*>(new QMouseEvent(type,    p, button, buttons, state)));
 
 
-        ret = bubblingSend(target, e, m_widget);
+        ret = bubblingSend(target, e.data(), m_widget);
 
+        if (!target)
+            break;
         if (needContextMenuEvent) {
             QContextMenuEvent cme(QContextMenuEvent::Mouse, p);
-            static_cast<EventPropagator *>(target)->sendEvent(&cme);
+            static_cast<EventPropagator *>(target.data())->sendEvent(&cme);
         } else if (type == QEvent::MouseMove && target->testAttribute(Qt::WA_Hover)) {
             QHoverEvent he( QEvent::HoverMove, p, p );
             QApplication::sendEvent(target, &he);
@@ -1124,7 +1122,6 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
         if (ev.id() == EventImpl::MOUSEUP_EVENT) {
             view()->setMouseEventsTarget( 0 );
         }
-        delete e;
         break;
     }
     case EventImpl::KEYDOWN_EVENT:
